"use strict";
var log4js = require("log4js");
var util = require("util");
var stream = require("stream");
var options = require("./options");
var Future = require("fibers/future");
var Logger = (function () {
    function Logger($config) {
        this.log4jsLogger = null;
        var appenders = [];
        if (!$config.CI_LOGGER) {
            appenders.push({
                type: "console",
                layout: {
                    type: "messagePassThrough"
                }
            });
        }
        log4js.configure({ appenders: appenders });
        this.log4jsLogger = log4js.getLogger();
        if (options.log) {
            this.log4jsLogger.setLevel(options.log);
        }
        else {
            this.log4jsLogger.setLevel($config.DEBUG ? "TRACE" : "INFO");
        }
    }
    Logger.prototype.setLevel = function (level) {
        this.log4jsLogger.setLevel(level);
    };
    Logger.prototype.fatal = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        this.log4jsLogger.fatal.apply(this.log4jsLogger, args);
    };
    Logger.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        this.log4jsLogger.error.apply(this.log4jsLogger, args);
    };
    Logger.prototype.warn = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        var message = util.format.apply(null, args);
        var colorizedMessage = message.yellow;
        this.log4jsLogger.warn.apply(this.log4jsLogger, [colorizedMessage]);
    };
    Logger.prototype.info = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        this.log4jsLogger.info.apply(this.log4jsLogger, args);
    };
    Logger.prototype.debug = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        this.log4jsLogger.debug.apply(this.log4jsLogger, args);
    };
    Logger.prototype.trace = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        this.log4jsLogger.trace.apply(this.log4jsLogger, args);
    };
    Logger.prototype.out = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        console.log(util.format.apply(null, args));
    };
    Logger.prototype.write = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        process.stdout.write(util.format.apply(null, args));
    };
    Logger.prototype.prepare = function (item) {
        if (typeof item === "undefined" || item === null) {
            return "[nothing]";
        }
        if (typeof item === "string") {
            return item;
        }
        if (item instanceof stream.Readable) {
            return "[ReadableStream]";
        }
        return JSON.stringify(item);
    };
    Logger.prototype.printInfoMessageOnSameLine = function (message) {
        if (!options.log || options.log === "info") {
            this.write(message);
        }
    };
    Logger.prototype.printMsgWithTimeout = function (message, timeout) {
        var _this = this;
        var printMsgFuture = new Future();
        setTimeout(function () {
            _this.printInfoMessageOnSameLine(message);
            printMsgFuture.return();
        }, timeout);
        return printMsgFuture;
    };
    return Logger;
})();
exports.Logger = Logger;
$injector.register("logger", Logger);
