"use strict";
var Future = require("fibers/future");
var hostInfo = require("../../host-info");
var MobileHelper = require("./../mobile-helper");
var options = require("./../../options");
var IosEmulatorServices = (function () {
    function IosEmulatorServices($logger, $emulatorSettingsService, $errors, $childProcess) {
        this.$logger = $logger;
        this.$emulatorSettingsService = $emulatorSettingsService;
        this.$errors = $errors;
        this.$childProcess = $childProcess;
    }
    IosEmulatorServices.prototype.checkDependencies = function () {
        return (function () {
        }).future()();
    };
    IosEmulatorServices.prototype.checkAvailability = function (dependsOnProject) {
        var _this = this;
        if (dependsOnProject === void 0) { dependsOnProject = true; }
        return (function () {
            if (!hostInfo.isDarwin()) {
                _this.$errors.fail("iOS Simulator is available only on Mac OS X.");
            }
            var platform = MobileHelper.DevicePlatforms[0 /* iOS */];
            if (dependsOnProject && !_this.$emulatorSettingsService.canStart(platform).wait()) {
                _this.$errors.fail("The current project does not target iOS and cannot be run in the iOS Simulator.");
            }
        }).future()();
    };
    IosEmulatorServices.prototype.startEmulator = function (app, emulatorOptions) {
        var _this = this;
        return (function () {
            _this.killLaunchdSim().wait();
            _this.startEmulatorCore(app, emulatorOptions);
        }).future()();
    };
    IosEmulatorServices.prototype.killLaunchdSim = function () {
        this.$logger.info("Cleaning up before starting the iOS Simulator");
        var future = new Future();
        var killAllProc = this.$childProcess.spawn("killall", ["launchd_sim"]);
        killAllProc.on("close", function (code) {
            future.return();
        });
        return future;
    };
    IosEmulatorServices.prototype.startEmulatorCore = function (app, emulatorOptions) {
        this.$logger.info("Starting iOS Simulator");
        var iosSimPath = require.resolve("ios-sim-portable");
        var nodeCommandName = process.argv[0];
        if (options.availableDevices) {
            this.$childProcess.spawnFromEvent(nodeCommandName, [iosSimPath, "device-types"], "close", { stdio: "inherit" }).wait();
            return;
        }
        var opts = [
            iosSimPath,
            "launch",
            app,
            "--timeout",
            options.timeout,
            "--exit"
        ];
        if (emulatorOptions) {
            if (emulatorOptions.stderrFilePath) {
                opts = opts.concat("--stderr", emulatorOptions.stderrFilePath);
            }
            if (emulatorOptions.stdoutFilePath) {
                opts = opts.concat("--stdout", emulatorOptions.stdoutFilePath);
            }
        }
        if (options.device) {
            opts = opts.concat("--device", options.device);
        }
        this.$childProcess.spawn(nodeCommandName, opts, { stdio: "inherit" });
    };
    return IosEmulatorServices;
})();
$injector.register("iOSEmulatorServices", IosEmulatorServices);
