"use strict";
var gaze = require("gaze");
var path = require("path");
var os = require("os");
var options = require("../options");
var Future = require("fibers/future");
var CancellationService = (function () {
    function CancellationService($fs, $logger, $errors) {
        this.$fs = $fs;
        this.$logger = $logger;
        this.$errors = $errors;
        this.watches = {};
        this.$fs.createDirectory(CancellationService.killSwitchDir).wait();
        this.$fs.chmod(CancellationService.killSwitchDir, "0777").wait();
    }
    CancellationService.prototype.begin = function (name) {
        var _this = this;
        return (function () {
            var triggerFile = CancellationService.makeKillSwitchFileName(name);
            var stream = _this.$fs.createWriteStream(triggerFile);
            var streamEnd = _this.$fs.futureFromEvent(stream, "finish");
            stream.end();
            streamEnd.wait();
            _this.$fs.chmod(triggerFile, "0777").wait();
            _this.$logger.trace("Starting watch on killswitch %s", triggerFile);
            var watcherInitialized = new Future();
            gaze(triggerFile, function (err, watcher) {
                this.on("deleted", function (filePath) { return process.exit(); });
                if (err) {
                    watcherInitialized.throw(err);
                }
                else {
                    watcherInitialized.return(watcher);
                }
            });
            var watcher = watcherInitialized.wait();
            if (watcher) {
                _this.watches[name] = watcher;
            }
        }).future()();
    };
    CancellationService.prototype.end = function (name) {
        var watcher = this.watches[name];
        delete this.watches[name];
        watcher.close();
    };
    CancellationService.prototype.dispose = function () {
        var _this = this;
        Object.keys(this.watches).forEach(function (name) {
            _this.end(name);
        });
    };
    Object.defineProperty(CancellationService, "killSwitchDir", {
        get: function () {
            return path.join(os.tmpDir(), process.env.SUDO_USER || process.env.USER || process.env.USERNAME, "KillSwitches");
        },
        enumerable: true,
        configurable: true
    });
    CancellationService.makeKillSwitchFileName = function (name) {
        return path.join(CancellationService.killSwitchDir, name);
    };
    return CancellationService;
})();
exports.CancellationService = CancellationService;
$injector.register("cancellation", CancellationService);
